## Weibo Text Analysis

### Introduction

This toolkit aims to provide key functions to preprocess key information from weibo text. 

### Installation

```commandline
    pip install weibo-text-analysis
```

### License

The `weibo-text-analysis` toolkit is provided by Donghua Chen with MIT License.